@@ -1,6 +1,6 @@
 /* upstart
  *
- * Copyright © 2009 Canonical Ltd.
+ * Copyright © 2010 Canonical Ltd.
  * Author: Scott James Remnant <scott@netsplit.com>.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -66,6 +66,7 @@ static void cad_handler     (void *data, NihSignal *signal);
 static void kbd_handler     (void *data, NihSignal *signal);
 static void pwr_handler     (void *data, NihSignal *signal);
 static void hup_handler     (void *data, NihSignal *signal);
+static void usr1_handler    (void *data, NihSignal *signal);
 #endif /* DEBUG */
 
 
@@ -172,6 +173,8 @@ main (int   argc,
 	 */
 	if (system_setup_console (CONSOLE_OUTPUT, (! restart)) < 0)
 		nih_free (nih_error_get ());
+	if (system_setup_console (CONSOLE_NONE, FALSE) < 0)
+		nih_free (nih_error_get ());
 
 	/* Set the PATH environment variable */
 	setenv ("PATH", PATH, TRUE);
@@ -234,6 +237,10 @@ main (int   argc,
 	/* SIGHUP instructs us to re-load our configuration */
 	nih_signal_set_handler (SIGHUP, nih_signal_handler);
 	NIH_MUST (nih_signal_add_handler (NULL, SIGHUP, hup_handler, NULL));
+
+	/* SIGUSR1 instructs us to reconnect to D-Bus */
+	nih_signal_set_handler (SIGUSR1, nih_signal_handler);
+	NIH_MUST (nih_signal_add_handler (NULL, SIGUSR1, usr1_handler, NULL));
 #endif /* DEBUG */
 
 
@@ -451,7 +458,20 @@ hup_handler (void      *data,
 {
 	nih_info (_("Reloading configuration"));
 	conf_reload ();
+}
 
+/**
+ * usr1_handler:
+ * @data: unused,
+ * @signal: signal that called this handler.
+ *
+ * Handle having recieved the SIGUSR signal, which we use to instruct us to
+ * reconnect to D-Bus.
+ **/
+static void
+usr1_handler (void      *data,
+	      NihSignal *signal)
+{
 	if (! control_bus) {
 		nih_info (_("Reconnecting to system bus"));
 
